<?php
namespace Ep\Woo\Product\View\Helper;

use Ep\Woo\Product\ProductInterface;
use Ep\Woo\Product\Simple;
use Zend\View\Helper\AbstractHelper;

/**
 * Renderira SaleBadge element.
 *
 * @package Ep\Woo\Produc\View\Helper
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-woocommerce
 */
class SaleBadge extends AbstractHelper
{
    protected $saleConfig;

    public function __construct(array $saleConfig)
    {
        $this->saleConfig = $saleConfig;
    }

    /**
     * Renderira element.
     *
     * @param ProductInterface $product
     *
     * @return string
     */
    public function __invoke($productOrCategory): string
    {
        if ($productOrCategory instanceof ProductInterface) {
            return $this->renderProduct($productOrCategory);
        } else if ($productOrCategory instanceof \WP_Term) {
            return $this->renderCategory($productOrCategory);
        }

        throw new \RuntimeException(sprintf("SaleBadge helper ne zna rendati '%s'.", get_class($productOrCategory)));
    }

    /**
     * @param \WP_Term $category
     */
    public function renderCategory(\WP_Term $category)
    {
        $text = get_term_meta($category->term_id, '_sale_badge_text', true) ?: '';
        $size = strtolower(get_term_meta($category->term_id, '_sale_badge_size', true) ?: 'none');

        if (empty($text) || 'none' === $size || $this->saleEnded()) {
            return '';
        }

        return sprintf('<span class="sale-badge-category sale-badge-category--%s">%s</span>', $size, $text);
    }

    /**
     * Renderira sale badge za proizvod.
     *
     * @param ProductInterface|Simple $product
     */
    public function renderProduct(ProductInterface $product)
    {
        if (!$product->isOnSale() || $product->is_price_hidden()) {
            return '';
        }

        $percentage = 100 - round($product->getSalePrice() / $product->getRegularPrice() * 100);

        return sprintf('<span class="sale-badge">-%d%%</span>', $percentage);
    }
    
    protected function saleEnded()
    {
        $endSale = $this->saleConfig['date_end_sale'];

        $now = new \DateTime('now');
        $end = new \DateTime($endSale);

        $saleIsActive = (bool)$this->saleConfig['active_sale'];

        if ($saleIsActive) return false;

        return ( $now > $end );
    }

}